# AiiDA GUI Apps
[![PyPI version](https://badge.fury.io/py/aiida-gui-apps.svg)](https://badge.fury.io/py/aiida-gui-apps)
[![Unit test](https://github.com/aiidateam/aiida-gui-apps/actions/workflows/ci.yaml/badge.svg)](https://github.com/aiidateam/aiida-gui-apps/actions/workflows/ci.yaml)
[![codecov](https://codecov.io/gh/aiidateam/aiida-gui-apps/branch/main/graph/badge.svg)](https://codecov.io/gh/aiidateam/aiida-gui-apps)
[![Docs status](https://readthedocs.org/projects/aiida-gui-apps/badge)](http://aiida-gui-apps.readthedocs.io/)

A collection of AiiDA GUI applications that provide a user-friendly interface for running and managing AiiDA workflows.

## Installation

```console
    pip install aiida-gui-apps
```

To install the latest version from source, first clone the repository and then install using `pip`:

```console
git clone https://github.com/aiidateam/aiida-gui-apps
cd aiida-gui-apps
pip install -e .
# build the frontend
cd frontend
npm install
npm run build
```


## Documentation
Explore the comprehensive [documentation](https://aiida-gui-apps.readthedocs.io/en/latest/) to discover all the features and capabilities of AiiDA GUI apps.


## License
[MIT](http://opensource.org/licenses/MIT)
